summaryrefslogtreecommitdiff
path: root/src/partest
diff options
context:
space:
mode:
authorTiark Rompf <tiark.rompf@epfl.ch>2009-10-21 21:13:58 +0000
committerTiark Rompf <tiark.rompf@epfl.ch>2009-10-21 21:13:58 +0000
commit2816f2e6ce51206b3b5bdb1367203bf688625cb6 (patch)
treeb624f91e8b6789f3cdbe216d7f9068edb6cb469b /src/partest
parentc570e1e7af9762a513f976e4fc5187a6a6efa271 (diff)
downloadscala-2816f2e6ce51206b3b5bdb1367203bf688625cb6.tar.gz
scala-2816f2e6ce51206b3b5bdb1367203bf688625cb6.tar.bz2
scala-2816f2e6ce51206b3b5bdb1367203bf688625cb6.zip
renamed Vector to IndexedSeq
Diffstat (limited to 'src/partest')
-rw-r--r--src/partest/scala/tools/partest/nest/Diff.java20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/partest/scala/tools/partest/nest/Diff.java b/src/partest/scala/tools/partest/nest/Diff.java
index 754f9bb91b..abd09d0293 100644
--- a/src/partest/scala/tools/partest/nest/Diff.java
+++ b/src/partest/scala/tools/partest/nest/Diff.java
@@ -4,7 +4,7 @@ package scala.tools.partest.nest;
import java.util.Hashtable;
/** A class to compare vectors of objects. The result of comparison
is a list of <code>change</code> objects which form an
edit script. The objects compared are traditionally lines
of text from two files. Comparison options such as "ignore
@@ -68,12 +68,12 @@ public class Diff {
set of changes. This makes things slower, sometimes much slower. */
public boolean no_discards = false;
- private int[] xvec, yvec; /* Vectors being compared. */
- private int[] fdiag; /* Vector, indexed by diagonal, containing
+ private int[] xvec, yvec; /* IndexedSeqs being compared. */
+ private int[] fdiag; /* IndexedSeq, indexed by diagonal, containing
the X coordinate of the point furthest
along the given diagonal in the forward
search of the edit matrix. */
- private int[] bdiag; /* Vector, indexed by diagonal, containing
+ private int[] bdiag; /* IndexedSeq, indexed by diagonal, containing
the X coordinate of the point furthest
along the given diagonal in the backward
search of the edit matrix. */
@@ -275,7 +275,7 @@ public class Diff {
/** Compare in detail contiguous subsequences of the two files
which are known, as a whole, to match each other.
- The results are recorded in the vectors filevec[N].changed_flag, by
+ The results are recorded in the IndexedSeqs filevec[N].changed_flag, by
storing a 1 in the element for each line that is an insertion or deletion.
The subsequence of file 0 is [XOFF, XLIM) and likewise for file 1.
@@ -538,7 +538,7 @@ public class Diff {
void clear() {
/* Allocate a flag for each line of each file, saying whether that line
is an insertion or deletion.
- Allocate an extra element, always zero, at each end of each vector.
+ Allocate an extra element, always zero, at each end of each IndexedSeq.
*/
changed_flag = new boolean[buffered_lines + 2];
}
@@ -849,16 +849,16 @@ public class Diff {
/** Number of elements (lines) in this file. */
final int buffered_lines;
- /** Vector, indexed by line number, containing an equivalence code for
- each line. It is this vector that is actually compared with that
+ /** IndexedSeq, indexed by line number, containing an equivalence code for
+ each line. It is this IndexedSeq that is actually compared with that
of another file to generate differences. */
private final int[] equivs;
/** Vector, like the previous one except that
the elements for discarded lines have been squeezed out. */
final int[] undiscarded;
/** Vector mapping virtual line numbers (not counting discarded lines)
to real ones (counting those lines). Both are origin-0. */
final int[] realindexes;
@@ -4,7 +4,7 @@ package scala.tools.partest.nest;
import java.util.Hashtable;
-/** A class to compare vectors of objects. The result of comparison
+/** A class to compare IndexedSeqs of objects. The result of comparison
is a list of <code>change</code> objects which form an
edit script. The objects compared are traditionally lines
@@ -849,16 +849,16 @@ public class Diff {
of another file to generate differences. */
private final int[] equivs;
- /** Vector, like the previous one except that
+ /** IndexedSeq, like the previous one except that
the elements for discarded lines have been squeezed out. */
final int[] undiscarded;
@@ -849,16 +849,16 @@ public class Diff {
the elements for discarded lines have been squeezed out. */
final int[] undiscarded;
- /** Vector mapping virtual line numbers (not counting discarded lines)
+ /** IndexedSeq mapping virtual line numbers (not counting discarded lines)
to real ones (counting those lines). Both are origin-0. */
final int[] realindexes;